==> cbang_0.0.0.tar.gz: cbang-1.3.2/src/cbang/json/BufferWriter.h <==
/******************************************************************************\

          This file is part of the C! library.  A.K.A the cbang library.

                Copyright (c) 2003-2019, Cauldron Development LLC
                   Copyright (c) 2003-2017, Stanford University
                               All rights reserved.

         The C! library is free software: you can redistribute it and/or
        modify it under the terms of the GNU Lesser General Public License
       as published by the Free Software Foundation, either version 2.1 of
               the License, or (at your option) any later version.

        The C! library is distributed in the hope that it will be useful,
          but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
                 Lesser General Public License for more details.

         You should have received a copy of the GNU Lesser General Public
                 License along with the C! library.  If not, see
                         <http://www.gnu.org/licenses/>.

        In addition, BSD licensing may be granted on a case by case basis
        by written permission from at least one of the copyright holders.
           You may request written permission by emailing the authors.

                  For information regarding this software email:
                                 Joseph Coffland
                          joseph@cauldrondevelopment.com

\******************************************************************************/

#pragma once

#include "Writer.h"

#include <cbang/iostream/VectorDevice.h>

#include <vector>

namespace cb {
  namespace JSON {
    class BufferWriter : public Writer {
      std::vector<char> buffer;
      VectorStream<char> stream;

    public:
      BufferWriter(unsigned indent = 0, bool compact = false,
                   output_mode_t mode = Writer::JSON_MODE) :
        Writer(stream, indent, compact, mode), stream(buffer) {}

#ifdef _WIN32
      const char *data() const {return &buffer[0];}
#else
      const char *data() const {return buffer.data();}
#endif

      size_t const size() const {return buffer.size();}
      std::string toString() const {return std::string(data(), size());}

      void flush() {stream.flush();}

      template <typename T, typename M>
      std::string toString(T obj, M member) {
        (*obj.*member)(*this);
        return toString();
      }
    };
  }
}

==> cbang-1.6.0.tar.gz: cbang-1.6.0/src/cbang/json/BufferWriter.h <==
/******************************************************************************\

          This file is part of the C! library.  A.K.A the cbang library.

                Copyright (c) 2003-2019, Cauldron Development LLC
                   Copyright (c) 2003-2017, Stanford University
                               All rights reserved.

         The C! library is free software: you can redistribute it and/or
        modify it under the terms of the GNU Lesser General Public License
       as published by the Free Software Foundation, either version 2.1 of
               the License, or (at your option) any later version.

        The C! library is distributed in the hope that it will be useful,
          but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
                 Lesser General Public License for more details.

         You should have received a copy of the GNU Lesser General Public
                 License along with the C! library.  If not, see
                         <http://www.gnu.org/licenses/>.

        In addition, BSD licensing may be granted on a case by case basis
        by written permission from at least one of the copyright holders.
           You may request written permission by emailing the authors.

                  For information regarding this software email:
                                 Joseph Coffland
                          joseph@cauldrondevelopment.com

\******************************************************************************/

#pragma once

#include "Writer.h"

#include <cbang/iostream/VectorDevice.h>

#include <vector>

namespace cb {
  namespace JSON {
    class BufferWriter : public Writer {
      std::vector<char> buffer;
      VectorStream<char> stream;

    public:
      BufferWriter(unsigned indentStart = 0, bool compact = false,
                   unsigned indentSpace = 2, int precision = 6) :
        Writer(stream, indentStart, compact, indentSpace, precision),
        stream(buffer) {}

#ifdef _WIN32
      const char *data() const {return &buffer[0];}
#else
      const char *data() const {return buffer.data();}
#endif

      size_t const size() const {return buffer.size();}
      std::string toString() const {return std::string(data(), size());}

      void flush() {stream.flush();}

      template <typename T, typename M>
      std::string toString(T obj, M member) {
        (*obj.*member)(*this);
        flush();
        return toString();
      }
    };
  }
}
